"""Shared choices for the different models."""

import ipaddress
from typing import Annotated

from annotated_types import doc
from pydantic import Field, PlainSerializer
from pydantic_forms.types import strEnum


class Vendor(strEnum):
    """Enumerator for the different product vendors that are supported."""

    JUNIPER = "juniper"
    NOKIA = "nokia"


PortNumber = Annotated[
    int,
    Field(
        gt=0,
        le=49151,
    ),
    doc(
    "Constrained integer for valid port numbers. The range from 49152 to 65535 is marked as ephemeral, "
    "and can therefore not be selected for permanent allocation."
),
]


IPv4AddressType = Annotated[
    ipaddress.IPv4Address, PlainSerializer(lambda ip: str(ip), return_type=str, when_used="always")
]

IPv6AddressType = Annotated[
    ipaddress.IPv6Address, PlainSerializer(lambda ip: str(ip), return_type=str, when_used="always")
]


class ConnectionStrategy(strEnum):
    """An enumerator for the connection Strategies."""

    IN_BAND = "IN BAND"
    OUT_OF_BAND = "OUT OF BAND"
